import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';
import 'package:ionicons/ionicons.dart';

import 'package:scrobbles/common/ui/pages/discoveries.dart';
import 'package:scrobbles/common/ui/pages/home.dart';
import 'package:scrobbles/common/ui/pages/statistics.dart';
import 'package:scrobbles/cubit/activity/activity_cubit.dart';
import 'package:scrobbles/models/activity/activity.dart';

class ActivityPageItem {
  final String code;
  final Icon icon;
  final Widget Function({required Activity currentActivity})? builder;

  const ActivityPageItem({
    required this.code,
    required this.icon,
    required this.builder,
  });
}

class ActivityPage {
  static const bool displayBottomNavBar = false;

  static const indexHome = 0;
  static final ActivityPageItem pageHome = ActivityPageItem(
    code: 'page_home',
    icon: Icon(Ionicons.home_outline),
    builder: ({required Activity currentActivity}) {
      return PageHome();
    },
  );

  static const indexDiscoveries = 1;
  static final ActivityPageItem pageDiscoveries = ActivityPageItem(
    code: 'page_discoveries',
    icon: Icon(Ionicons.star_outline),
    builder: ({required Activity currentActivity}) {
      return PageDiscoveries();
    },
  );

  static const indexStatistics = 2;
  static final ActivityPageItem pageStatistics = ActivityPageItem(
    code: 'page_statistics',
    icon: Icon(Ionicons.bar_chart_outline),
    builder: ({required Activity currentActivity}) {
      return PageStatistics();
    },
  );

  static Map<int, ActivityPageItem> items = {
    indexHome: pageHome,
    indexDiscoveries: pageDiscoveries,
    indexStatistics: pageStatistics,
  };

  static int defaultPageIndex = indexHome;

  static bool isIndexAllowed(int pageIndex) {
    return items.keys.contains(pageIndex);
  }

  static Widget getWidget(int pageIndex) {
    return BlocBuilder<ActivityCubit, ActivityState>(
      builder: (BuildContext context, ActivityState activityState) {
        final Activity currentActivity = activityState.currentActivity;

        if (items.keys.contains(pageIndex)) {
          return items[pageIndex]?.builder!(currentActivity: currentActivity) ?? Text('oups');
        } else {
          return getWidget(defaultPageIndex);
        }
      },
    );
  }
}
